Module strategy

Module strategy 

Structs

LdmParams
Parameters for Long Distance Matching.
LevelParams
Compression parameters for a specific level.
Options
Options for large-window and LDM compression, orthogonal to level.

Enums

Strategy
Match-finding strategy.

Constants

DEFAULT_LEVEL
Default compression level used when level 0 is requested.
HASH_LOG_MAX
HASH_LOG_MIN

Functions

apply_options
level_params
Returns the compression parameters for a given level, or None if out of range.
level_params_for_size
Returns the compression parameters for a given level, sized for src_len.
max_hash_log
Returns the maximum hash_log for a given level. Used by CompressContext to pre-allocate hash tables.